@@ -201,7 +201,7 @@ empathy_avatar_chooser_class_init (EmpathyAvatarChooserClass *klass)
             G_SIGNAL_RUN_LAST,
             0,
             NULL, NULL,
-            g_cclosure_marshal_VOID__VOID,
+            g_cclosure_marshal_generic,
             G_TYPE_NONE, 0);
 
   /**
